@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from datetime import datetime
 
 from rich.console import Console
@@ -13,3 +15,7 @@ def ts2dt(timestamp: float) -> str:
         + " [bright_green]"
         + dt.time().strftime("%H:%M:%S")
     )
+
+
+def includes(args: list[str], flags: set[str]) -> bool:
+    return any(s in args for s in flags)
